# -*- coding: utf-8 -*-
from django import template
from django.contrib.sites.models import get_current_site

from sekizai.templatetags.sekizai_tags import AddData
from classytags.core import Options
from classytags.arguments import Argument
from classytags.helpers import InclusionTag

from social_tags import networks, settings


register = template.Library()


class MetaObject(object):

    def __init__(self, kwargs):
        self.kwargs = kwargs

    @property
    def objects(self):
        objects = []
        for type, object in networks.AVAILABLE.iteritems():
            objects.append(getattr(networks, object)(**self.kwargs))
        return objects


#######################################
# Default Tags
#######################################

class RenderMetaTags(InclusionTag):
    name = 'render_meta_tags'
    template = 'social_tags/meta.html'

    options = Options(
        Argument('data'),
    )

    def get_context(self, context, data):
        kwargs = self.get_request_data(context['request'])
        kwargs.update(context['social_tags'])
        for key, value, network in data:
            if network:
                if not hasattr(kwargs, network):
                    kwargs[network] = {}
                kwargs[network][key] = value
            else:
                kwargs[key] = value
        kwargs['request'] = context['request']
        return {'objects': MetaObject(kwargs).objects}

    def get_request_data(self, request):
        data = {
            'url': request.build_absolute_uri(),
            'locale': request.LANGUAGE_CODE,
            'title': settings.DEFAULT_TITLE or get_current_site(request).name,
        }
        return data
register.tag(RenderMetaTags)


class SetTag(AddData):
    name = 'set_tag'

    def render_tag(self, context, key, value):
        varname = getattr(settings, 'SEKIZAI_VARNAME', 'SEKIZAI_CONTENT_HOLDER')
        context[varname]['social_tags'].append((key, value, None))
        return ''
register.tag(SetTag)


#######################################
# Open Graph
#######################################

class CustomOpenGraph(AddData):
    name = 'opengraph'

    def render_tag(self, context, key, value):
        varname = getattr(settings, 'SEKIZAI_VARNAME', 'SEKIZAI_CONTENT_HOLDER')
        context[varname]['social_tags'].append((key, value, 'opengraph'))
        return ''
register.tag(CustomOpenGraph)


# -*- coding: utf-8 -*-
from social_tags.objects import RenderObject


AVAILABLE = {
    'opengraph': 'OpenGraph',
}

class OpenGraph(RenderObject):
    template = 'social_tags/networks/opengraph.html'

    def prepare_context(self, context):
        for key, value in context.iteritems():
            context[key] = value
        context['locales'] = [l for l in context['locales'] if l != context['locale']]
        return context


# -*- coding: utf-8 -*-
from setuptools import setup, find_packages

import os


APP = 'social_tags'
VERSION = __import__(APP).__version__
AUTHOR = 'Pascal Mouret'
NAME = 'django-social-tags'
URL = 'https://github.com/pascalmouret/django-social'
AUTHOR_MAIL = 'pascal.mouret@divio.ch'
DESCRIPTION = 'Social meta-tag handler for Django.'
README = 'README.md'

REQUIREMENTS = [
	'django-sekizai',
]

CLASSIFIERS = [
    'Environment :: Web Environment',
    'Framework :: Django',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: BSD License',
    'Operating System :: OS Independent',
    'Programming Language :: Python',
    'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    'Topic :: Software Development',
    'Topic :: Software Development :: Libraries :: Application Frameworks',
    ]

# make it work
if not 'a' in VERSION and not 'b' in VERSION: CLASSIFIERS.append('Development Status :: 5 - Production/Stable')
elif 'a' in VERSION: CLASSIFIERS.append('Development Status :: 3 - Alpha')
elif 'b' in VERSION: CLASSIFIERS.append('Development Status :: 4 - Beta')

def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(
    name=NAME,
    version=VERSION,
    author=AUTHOR,
    author_email=AUTHOR_MAIL,
    description=DESCRIPTION,
    long_description=read(README),
    url=URL,
    classifiers=CLASSIFIERS,
    platforms=['OS Independent'],
    install_requires=REQUIREMENTS,
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False
)


# -*- coding: utf-8 -*-
from django.conf import settings


DEFAULT_DEFAULT_TITLE = None
DEFAULT_DEFAULT_IMAGE = None
DEFAULT_DEFAULT_TYPE = None
DEFAULT_DEFAULT_LOCALE = settings.LANGUAGE_CODE
DEFAULT_DEFAULT_LOCALES = [l[0] for l in settings.LANGUAGES]


DEFAULT_TITLE = getattr(settings, 'SOCIAL_TAGS_DEFAULT_TITLE', DEFAULT_DEFAULT_TITLE)
DEFAULT_IMAGE = getattr(settings, 'SOCIAL_TAGS_DEFAULT_IMAGE', DEFAULT_DEFAULT_IMAGE)
DEFAULT_TYPE = getattr(settings, 'SOCIAL_TAGS_DEFAULT_TYPE', DEFAULT_DEFAULT_TYPE)
DEFAULT_LOCALE = getattr(settings, 'SOCIAL_TAGS_DEFAULT_LOCALE', DEFAULT_DEFAULT_LOCALE)
DEFAULT_LOCALES = getattr(settings, 'SOCIAL_TAGS_DEFAULT_LOCALES', DEFAULT_DEFAULT_LOCALES)


# -*- coding: utf-8 -*-
from django.template.loader import get_template
from django.template.context import Context


class RenderObject(object):
    template = None

    def __init__(self, **kwargs):
        self.kwargs = kwargs
        self.request = kwargs['request']

    def prepare_context(self, context):
        return context

    def render(self):
        if not self.template:
            raise Exception('No template defined.')
        t = get_template(self.template)
        c = Context(self.prepare_context(self.kwargs))
        return t.render(c)